﻿/**
 * jQuery.qeeree - Query String parsing library.
 *
 * Written by Mark Smith (mark.smith@practicalpoetry.co.uk)
 * Date: 2011/11/04
 *
 * @author Mark Smith
 * @version 0.0.2dev
 *
 * Copyright 2011 Mark Smith
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/
(function($) {
    "use strict";
    var _params = undefined;

    function parseQuery(qs) {
        qs = qs || location.search.substring(1);
        var result = {},
            re = /([^&=]+)=([^&]*)/g, m;

        while (m = re.exec(qs)) {
            result[decodeURIComponent(m[1])] = decodeURIComponent(m[2]);
        }

        _params = result;
    }

    $.qeeree = {
        _parse: parseQuery,
        get: function(key) {
            if (typeof _params === "undefined") {
                parseQuery();
            }
            return _params[key];
        },
        getKeys: function() {
            if (typeof _params === "undefined") {
                parseQuery();
            }
            return $.map(_params, function(value, key) { return key; });
        },
        containsKey: function(key) { 
            if (typeof _params === "undefined") {
                parseQuery();
            }
            return _params[key] !== undefined;
        }
    };
})(jQuery);
